FractalUpAttribute class

Implementers

Constructors

FractalUpAttribute(dynamic value, String type)
FractalUpAttribute.bool(bool value)
factory
FractalUpAttribute.double(double value)
factory
FractalUpAttribute.int(int value)
factory
FractalUpAttribute.string(String value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final
value → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited