FractalUpMessage class

Constructors

FractalUpMessage(String formatted, {String? template, List? params, Map<String, dynamic>? unknown})

Properties

formatted String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
params List?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
template String?
getter/setter pair
unknown Map<String, dynamic>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited