FractalUpMetrics class

Constructors

FractalUpMetrics()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

count(String name, int value, {Map<String, FractalUpAttribute>? attributes}) → void
distribution(String name, num value, {String? unit, Map<String, FractalUpAttribute>? attributes}) → void
flush() Future<void>
gauge(String name, num value, {String? unit, Map<String, FractalUpAttribute>? attributes}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited