FractalUpMobile class

Properties

config Config?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
platformVersion Future<String?>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addHTTPHeadersTrackingFor(List<String> headers) → void
crashNow({String? name}) → void
currentSessionId() Future<String>
endInteraction(String interactionId) → void
getAgentConfiguration() Config
getHTTPHeadersTrackingFor() Future
incrementAttribute(String name, {double? value}) Future<bool>
log(LogLevel logLevel, String message) → void
logAll(Exception exception, Map<String, dynamic>? attributes) → void
logAttributes(Map<String, dynamic>? attributes) → void
logDebug(String message) → void
logError(String message) → void
logInfo(String message) → void
logVerbose(String message) → void
logWarning(String message) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
noticeDistributedTrace(Map<String, dynamic> requestAttributes) Future<Map<String, dynamic>>
noticeHttpTransaction(String url, String httpMethod, int statusCode, int startTime, int endTime, int bytesSent, int bytesReceived, Map<String, dynamic>? traceData, {Map<String, dynamic>? httpParams, String responseBody = ''}) Future<void>
noticeNetworkFailure(String url, String httpMethod, int startTime, int endTime, NetworkFailure errorCode) Future<void>
recordBreadcrumb(String name, {Map<String, dynamic>? eventAttributes}) Future<bool>
recordCustomEvent(String eventType, {String eventName = '', Map<String, dynamic>? eventAttributes}) Future<bool>
recordError(Object error, StackTrace? stackTrace, {Map<String, dynamic>? attributes, bool isFatal = false}) → void
recordMetric(String name, String category, {double? value, MetricUnit? countUnit, MetricUnit? valueUnit}) Future<void>
redirectDebugPrint() → void
removeAttribute(String name) Future<bool>
setAgentConfiguration(Config config) → void
setAttribute(String name, dynamic value) Future<bool>
setInteractionName(String interactionName) Future<void>
setMaxEventBufferTime(int maxBufferTimeInSec) Future<void>
setMaxEventPoolSize(int maxSize) Future<void>
setMaxOfflineStorageSize(int megaBytes) Future<void>
setUserId(String userId) Future<bool?>
shutDown() Future<void>
start(Config config, Function runApp) Future<void>
startAgent(Config config) Future<void>
startInteraction(String actionName) Future<String>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance FractalUpMobile
final

Static Methods

getStackTraceElements(StackTrace stackTrace) List<Map<String, String>>
onError(FlutterErrorDetails errorDetails) → void