FractalUpNavigatorObserver class

Inheritance

Constructors

FractalUpNavigatorObserver({dynamic hub, bool enableAutoTransactions = true, bool enableNewTraceOnNavigation = false, Duration autoFinishAfter = const Duration(seconds: 3), bool setRouteNameAsTransaction = false, RouteNameExtractor? routeNameExtractor, AdditionalInfoExtractor? additionalInfoProvider, List<String>? ignoreRoutes})

Properties

additionalInfoProvider AdditionalInfoExtractor?
finalinherited
autoFinishAfter Duration
finalinherited
enableAutoTransactions bool
finalinherited
enableNewTraceOnNavigation bool
finalinherited
hashCode int
The hash code for this object.
no setterinherited
ignoreRoutes List<String>
finalinherited
The navigator that the observer is observing, if any.
no setterinherited
routeNameExtractor RouteNameExtractor?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setRouteNameAsTransaction bool
finalinherited
trackPreviousViewOnPop bool
finalinherited

Methods

debugObservingRoute(PageRoute route) bool
Whether this observer is managing changes for the specified route.
inherited
didChangeTop(Route topRoute, Route? previousTopRoute) → void
The top most route has changed.
inherited
didPop(Route route, Route? previousRoute) → void
The Navigator popped route.
inherited
didPush(Route route, Route? previousRoute) → void
The Navigator pushed route.
inherited
didRemove(Route route, Route? previousRoute) → void
The Navigator removed route.
inherited
didReplace({Route? newRoute, Route? oldRoute}) → void
The Navigator replaced oldRoute with newRoute.
inherited
didStartUserGesture(Route route, Route? previousRoute) → void
The Navigator's routes are being moved by a user gesture.
inherited
didStopUserGesture() → void
User gesture is no longer controlling the Navigator.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
subscribe(RouteAware routeAware, PageRoute route) → void
Subscribe routeAware to be informed about changes to route.
inherited
toString() String
A string representation of this object.
inherited
unsubscribe(RouteAware routeAware) → void
Unsubscribe routeAware.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

currentRouteName String?
no setter