FractalUpSession class

Constructors

FractalUpSession({required String id, required DateTime startedAt, DateTime? endedAt, int sequence = 0, int errorCount = 0, bool crashed = false})
FractalUpSession.start({String? id, DateTime? startedAt, String idGenerator()?})
factory

Properties

crashed bool
final
endedAt DateTime?
final
errorCount int
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sequence int
final
startedAt DateTime
final
status String
no setter

Methods

end([DateTime? endedAt]) FractalUpSession
nextEvent({bool errored = false, bool crashed = false}) FractalUpSession
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited