FractalUpTraceHeader class

Constructors

FractalUpTraceHeader(FractalUpId traceId, SpanId spanId, {bool? sampled})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampled bool?
final
spanId SpanId
final
traceId FractalUpId
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited