FractalupRadarClient class

Constructors

FractalupRadarClient(FractalupRadarOptions options, {Client? httpClient})

Properties

currentSession FractalUpSession
no setter
currentSessionId String
no setter
deduplicatedEvents int
no setter
droppedEvents int
no setter
hashCode int
The hash code for this object.
no setterinherited
options FractalupRadarOptions
final
queuedEvents int
no setter
rateLimitedEvents int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

capture(String eventName, {String? eventId, String eventType = 'radar.flutter', String source = 'flutter', String level = 'info', String? message, Map<String, Object?> attributes = const {}, Map<String, Object?> tags = const {}, Map<String, Object?> contexts = const {}, Map<String, String> requestHeaders = const {}, String? fingerprint, String? eventKey, String? traceId, String? spanId}) Future<FractalupRadarResponse>
captureError(Object error, StackTrace stackTrace, {String? eventId, String eventName = 'fractalup.event', String eventType = 'flutter.error', String source = 'flutter_error', String? message, bool handled = true, bool fatal = false, Map<String, Object?> attributes = const {}, Map<String, Object?> tags = const {}, Map<String, Object?> contexts = const {}, Map<String, String> requestHeaders = const {}, String? fingerprint, String? eventKey, String? traceId, String? spanId}) Future<FractalupRadarResponse>
captureEvent(FractalUpEvent event) Future<FractalupRadarResponse>
captureFuture<T>(Future<T> future, {Map<String, Object?> attributes = const {}, Map<String, Object?> tags = const {}, Map<String, Object?> contexts = const {}, Map<String, String> requestHeaders = const {}}) Future<T>
clearUser() → void
close() → void
enqueue(String eventName, {String? eventId, String eventType = 'radar.flutter', String source = 'flutter', String level = 'info', String? message, Map<String, Object?> attributes = const {}, Map<String, Object?> tags = const {}, Map<String, Object?> contexts = const {}, Map<String, String> requestHeaders = const {}, String? fingerprint, String? eventKey, String? traceId, String? spanId}) bool
enqueueCanonicalEvent(FractalUpEvent event) bool
enqueueEvent(FractalupRadarEvent event) bool
flush() Future<void>
installFlutterErrorHooks({bool captureFlutterErrors = true, bool capturePlatformDispatcherErrors = true, bool preserveExistingHandlers = true}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendEvent(FractalupRadarEvent event) Future<FractalupRadarResponse>
sendEvents(List<FractalupRadarEvent> events) Future<FractalupRadarResponse>
setUser({String? tenantId, String? userId}) → void
shutdown({bool flushQueuedEvents = true}) Future<void>
startSession({String? id, DateTime? startedAt}) → void
stopSession({DateTime? endedAt}) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited