Hub class

Implementers

Constructors

Hub([FractalUpOptions? options])

Properties

hashCode int
The hash code for this object.
no setterinherited
isEnabled bool
no setter
lastEventId FractalUpId
no setter
options FractalUpOptions
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addBreadcrumb(FractalUpBreadcrumb breadcrumb, {FractalUpHint? hint}) Future<void>
captureEvent(FractalUpEvent event, {dynamic stackTrace, FractalUpHint? hint, FractalUpScopeCallback? withScope}) Future<FractalUpId>
clone() Hub
configureScope(FractalUpScopeCallback callback) FutureOr<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited