Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- bit → const String
- byte → const String
- day → const String
- exabyte → const String
- exbibyte → const String
- gibibyte → const String
- gigabyte → const String
- hour → const String
- kibibyte → const String
- kilobyte → const String
- mebibyte → const String
- megabyte → const String
- microsecond → const String
- millisecond → const String
- minute → const String
- nanosecond → const String
- pebibyte → const String
- percent → const String
- petabyte → const String
- ratio → const String
- second → const String
- tebibyte → const String
- terabyte → const String
- week → const String