IFractalUpSpan class abstract
Constructors
Properties
- context → FractalUpSpanContext
-
no setter
- endTimestamp → DateTime?
-
no setter
- finished → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- origin ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startTimestamp → DateTime
-
no setter
- status ↔ SpanStatus?
-
getter/setter pair
- throwable ↔ dynamic
-
getter/setter pair
Methods
-
finish(
{SpanStatus? status, DateTime? endTimestamp, FractalUpHint? hint}) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeData(
String key) → void -
removeTag(
String key) → void -
scheduleFinish(
) → void -
setData(
String key, dynamic value) → void -
setMeasurement(
String name, num value, {dynamic unit}) → void -
setTag(
String key, String value) → void -
startChild(
String operation, {String? description, DateTime? startTimestamp}) → IFractalUpSpan -
toBaggageHeader(
) → FractalUpBaggageHeader? -
toFractalUpTrace(
) → FractalUpTraceHeader -
toString(
) → String -
A string representation of this object.
inherited
-
traceContext(
) → dynamic
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited